#!/bin/bash

PATCH_DIR=$(cd $(dirname "$0");pwd)
if [ $# -eq 0 ]; then
	TARGET_DIR="$PATCH_DIR"
elif [ $# -eq 1 ]; then
	TARGET_DIR=$(cd "$1";pwd)
else
	echo "Usage: ./update.sh soldatserver_dir"
	echo "If you want to patch multiple servers at the same time you can use the *nix utility find:"
	echo "Example: find server* -maxdepth 0 -exec ./update.sh \"{}\" \\;"
	exit
fi

if [ ! -d "$TARGET_DIR" ]; then
        echo "Usage: ./update.sh soldatserver_dir"
        exit
fi

if [ ! -f "$TARGET_DIR/soldat.ini" ]; then
        echo "Usage: ./update.sh soldatserver_dir"
        exit
fi

echo "Patching server: $TARGET_DIR"

cd $TARGET_DIR

if [ $(grep "MinWaveRespawn_Time" ./soldat.ini | wc -l) -eq 1 ]; then
        echo "Server is already 2.7.0 or newer"
        exit
fi

if [ "$PATCH_DIR" != "$TARGET_DIR" ]; then
	cp -r $PATCH_DIR/* .
fi

rm -rf ./update.txt ./update.sh ./BattlEye ./soldatserver.exe ./maps/ctf_Death2.PMS ./maps/ctf_Dropdown2.PMS ./maps/ctf_Maya2.PMS ./maps/ctf_MFM2.PMS
sed -i 's/WaveRespawn_Time=\(.*\)/MinWaveRespawn_Time=120\nMaxWaveRespawn_Time=\1/' ./soldat.ini
sed -i 's/\(Radio=.*\)/\1\nAntiSpy_Chat=0/' ./soldat.ini
sed -i 's/\(Advanced_Spectate.*\)/\1\nExternal_Anti_Cheat=0/' ./soldat.ini
sed -i 's/Raycasting_Quality.*//' ./soldat.ini
chmod +x ./soldatserver

echo "Patched!"
